@@ -68,6 +68,33 @@ class Utilities(object):
         logger.info(response.json())
         return response
         pass
+    def check_status_code_no_response_body(self,
+                          endPoint=None,
+                          requestMethod="GET",
+                          user="Captain_America",
+                          params=None,
+                          expectedStatusCode=requests.codes.ok,
+                          jsonPayload=None, token=None):
+        if token!= None:
+            headers = {'Content-Type': 'application/json',
+                      'X-Zeta-AuthToken': token}
+        elif user == "userStaticToken":
+            headers = functionalParm.getTokenCardApplication(user)
+        elif user != 'null':
+            headers = functionalParm.getHeader(user)
+        else:
+            headers = None
+
+        if endPoint.find("ifi/151613") == -1 and get_stage() == "beta":
+            endpoint = endPoint.replace("ifi/151613", "fi/13")
+        response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
+        logger.info(f"status code{response.status_code}")
+        assert response.status_code == expectedStatusCode, \
+            f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match"
+
+    def assert_error_message(self,response,errorKey,errorMessage):
+        if response:
+            assert response.json().get(errorKey) == errorMessage
         
         
     def check_status_code(self,
